==> jc-1.4.0.tar.gz: soot/jimple/toolkits/pointer/DependenceGraph__24Edge.h <==
// public class soot.jimple.toolkits.pointer.DependenceGraph$Edge

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class b1faf3d539d8e087 soot_jimple_toolkits_pointer_DependenceGraph__24Edge

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_toolkits_pointer_DependenceGraph__24Edge_H_
#define _JC_soot_jimple_toolkits_pointer_DependenceGraph__24Edge_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_soot_jimple_toolkits_pointer_DependenceGraph$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_pointer_DependenceGraph__24Edge$sub_refs	_jc_soot_jimple_toolkits_pointer_DependenceGraph__24Edge$sub_refs;
typedef struct _jc_soot_jimple_toolkits_pointer_DependenceGraph__24Edge$sub_nonrefs	_jc_soot_jimple_toolkits_pointer_DependenceGraph__24Edge$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_DependenceGraph__24Edge$refs	_jc_soot_jimple_toolkits_pointer_DependenceGraph__24Edge$refs;
typedef struct _jc_soot_jimple_toolkits_pointer_DependenceGraph__24Edge$nonrefs	_jc_soot_jimple_toolkits_pointer_DependenceGraph__24Edge$nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_DependenceGraph__24Edge$object	_jc_soot_jimple_toolkits_pointer_DependenceGraph__24Edge$object;

typedef const struct _jc_soot_jimple_toolkits_pointer_DependenceGraph__24Edge$vmethods	_jc_soot_jimple_toolkits_pointer_DependenceGraph__24Edge$vmethods;
typedef const struct _jc_soot_jimple_toolkits_pointer_DependenceGraph__24Edge$vtable	_jc_soot_jimple_toolkits_pointer_DependenceGraph__24Edge$vtable;
typedef const struct _jc_soot_jimple_toolkits_pointer_DependenceGraph__24Edge$vtype	_jc_soot_jimple_toolkits_pointer_DependenceGraph__24Edge$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_pointer_DependenceGraph__24Edge$method$_init$5b5a879ae6613fcd(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_DependenceGraph__24Edge$object *, struct _jc_soot_jimple_toolkits_pointer_DependenceGraph$object *, jshort, jshort);

// Virtual methods
extern jboolean _jc_soot_jimple_toolkits_pointer_DependenceGraph__24Edge$method$equals$8a15e0625571c581(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_DependenceGraph__24Edge$object *, struct _jc_java_lang_Object$object *);
extern jint _jc_soot_jimple_toolkits_pointer_DependenceGraph__24Edge$method$hashCode$53152098849316df(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_DependenceGraph__24Edge$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_pointer_DependenceGraph__24Edge$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_soot_jimple_toolkits_pointer_DependenceGraph__24Edge$method_info$hashCode$53152098849316df;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_pointer_DependenceGraph__24Edge$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_DependenceGraph__24Edge$object *, struct _jc_java_lang_Object$object *);
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_DependenceGraph__24Edge$object *);
};

// Vtable
struct _jc_soot_jimple_toolkits_pointer_DependenceGraph__24Edge$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_pointer_DependenceGraph__24Edge$vmethods	soot_jimple_toolkits_pointer_DependenceGraph__24Edge;
};

// Vtype
struct _jc_soot_jimple_toolkits_pointer_DependenceGraph__24Edge$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_pointer_DependenceGraph__24Edge$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_DependenceGraph__24Edge$sub_refs {
	struct _jc_soot_jimple_toolkits_pointer_DependenceGraph$object	*this__240;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_DependenceGraph__24Edge$refs {
    _jc_soot_jimple_toolkits_pointer_DependenceGraph__24Edge$sub_refs	soot_jimple_toolkits_pointer_DependenceGraph__24Edge;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_DependenceGraph__24Edge$sub_nonrefs {
	jshort	from;
	jshort	to;
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_DependenceGraph__24Edge$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_pointer_DependenceGraph__24Edge$sub_nonrefs	soot_jimple_toolkits_pointer_DependenceGraph__24Edge;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_pointer_DependenceGraph__24Edge$object {
	_jc_soot_jimple_toolkits_pointer_DependenceGraph__24Edge$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_pointer_DependenceGraph__24Edge$vtype	*vtype;
	_jc_soot_jimple_toolkits_pointer_DependenceGraph__24Edge$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_pointer_DependenceGraph__24Edge$vtype _jc_soot_jimple_toolkits_pointer_DependenceGraph__24Edge$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_pointer_DependenceGraph__24Edge, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_pointer_DependenceGraph__24Edge$class_object;

#endif	/* _JC_soot_jimple_toolkits_pointer_DependenceGraph__24Edge_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/toolkits/pointer/DependenceGraph__24Edge.h <==
// public class soot.jimple.toolkits.pointer.DependenceGraph$Edge

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b1faf3d539d8e087 soot_jimple_toolkits_pointer_DependenceGraph__24Edge

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_toolkits_pointer_DependenceGraph__24Edge_H_
#define _JC_soot_jimple_toolkits_pointer_DependenceGraph__24Edge_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_soot_jimple_toolkits_pointer_DependenceGraph$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_pointer_DependenceGraph__24Edge$sub_refs	_jc_soot_jimple_toolkits_pointer_DependenceGraph__24Edge$sub_refs;
typedef struct _jc_soot_jimple_toolkits_pointer_DependenceGraph__24Edge$sub_nonrefs	_jc_soot_jimple_toolkits_pointer_DependenceGraph__24Edge$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_DependenceGraph__24Edge$refs	_jc_soot_jimple_toolkits_pointer_DependenceGraph__24Edge$refs;
typedef struct _jc_soot_jimple_toolkits_pointer_DependenceGraph__24Edge$nonrefs	_jc_soot_jimple_toolkits_pointer_DependenceGraph__24Edge$nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_DependenceGraph__24Edge$object	_jc_soot_jimple_toolkits_pointer_DependenceGraph__24Edge$object;

typedef const struct _jc_soot_jimple_toolkits_pointer_DependenceGraph__24Edge$vmethods	_jc_soot_jimple_toolkits_pointer_DependenceGraph__24Edge$vmethods;
typedef const struct _jc_soot_jimple_toolkits_pointer_DependenceGraph__24Edge$vtable	_jc_soot_jimple_toolkits_pointer_DependenceGraph__24Edge$vtable;
typedef const struct _jc_soot_jimple_toolkits_pointer_DependenceGraph__24Edge$vtype	_jc_soot_jimple_toolkits_pointer_DependenceGraph__24Edge$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_pointer_DependenceGraph__24Edge$method$_init$5b5a879ae6613fcd(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_DependenceGraph__24Edge$object *, struct _jc_soot_jimple_toolkits_pointer_DependenceGraph$object *, jshort, jshort) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_soot_jimple_toolkits_pointer_DependenceGraph__24Edge$method$equals$8a15e0625571c581(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_DependenceGraph__24Edge$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_jimple_toolkits_pointer_DependenceGraph__24Edge$method$hashCode$53152098849316df(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_DependenceGraph__24Edge$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_pointer_DependenceGraph__24Edge$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_soot_jimple_toolkits_pointer_DependenceGraph__24Edge$method_info$hashCode$53152098849316df;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_pointer_DependenceGraph__24Edge$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_DependenceGraph__24Edge$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_DependenceGraph__24Edge$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_toolkits_pointer_DependenceGraph__24Edge$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_pointer_DependenceGraph__24Edge$vmethods	soot_jimple_toolkits_pointer_DependenceGraph__24Edge;
};

// Vtype
struct _jc_soot_jimple_toolkits_pointer_DependenceGraph__24Edge$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_pointer_DependenceGraph__24Edge$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_DependenceGraph__24Edge$sub_refs {
	struct _jc_soot_jimple_toolkits_pointer_DependenceGraph$object	*this__240;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_DependenceGraph__24Edge$refs {
    _jc_soot_jimple_toolkits_pointer_DependenceGraph__24Edge$sub_refs	soot_jimple_toolkits_pointer_DependenceGraph__24Edge;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_DependenceGraph__24Edge$sub_nonrefs {
	jshort	from;
	jshort	to;
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_DependenceGraph__24Edge$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_pointer_DependenceGraph__24Edge$sub_nonrefs	soot_jimple_toolkits_pointer_DependenceGraph__24Edge;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_pointer_DependenceGraph__24Edge$object {
	_jc_soot_jimple_toolkits_pointer_DependenceGraph__24Edge$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_pointer_DependenceGraph__24Edge$vtype	*vtype;
	_jc_soot_jimple_toolkits_pointer_DependenceGraph__24Edge$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_pointer_DependenceGraph__24Edge$vtype _jc_soot_jimple_toolkits_pointer_DependenceGraph__24Edge$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_pointer_DependenceGraph__24Edge, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_pointer_DependenceGraph__24Edge$class_object;

#endif	/* _JC_soot_jimple_toolkits_pointer_DependenceGraph__24Edge_H_ */
